database_stein_watkins_mini: Database of elliptic curves (small version)
========================================================================

Description
-----------

The Stein-Watkins database of elliptic curves (small version)

See http://modular.math.washington.edu/papers/stein-watkins/

This is an optional package, not included by default.

License
-------

Public Domain
